package examples.visitor.java;

/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This file is part of the design patterns project at UBC
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * either http:*www.mozilla.org/MPL/ or http:*aspectj.org/MPL/.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ca.ubc.cs.spl.pattern.
 *
 * Contributor(s):   
 */

/**
 * Implements a concrete element of the aggregate strcuture. This is a 
 * terminal binary tree element (leaf).
 *
 * @author  Jan Hannemann
 * @author  Gregor Kiczales
 * @version 1.0, 06/13/02
 * 
 * @see Node
 * @see NodeVisitor
 */

public class Leaf implements Node {  
    
    /**
     * the value stored in this leaf
     */

	protected int value;
	
    /**
     * Accepts a visitor and calls <code>visitRegularNode(Node) on it.
     *
     * @param nv the NodeVisitor that is to be accepted.
     */
     
	public void accept(NodeVisitor nv) {
		nv.visitLeaf(this);
	}
	
    /**
     * Creates a new Leaf with the given value.
     *
     * @param v the value of the leaf
     */
    
	public Leaf(int v) {
		value = v;
	} 
	
	/** 
	 * Accessor for the leaf's value
	 *
	 * @returns the leaf's value
	 */
	 
	public int getValue() {
	    return value;
	}
}